@@ -15,25 +15,25 @@
 ####
 ####**********************************************************************
 ####**********************************************************************
-#' Minimal depth data object (\code{randomForestSRC::var.select})
+#' Minimal depth data object (\code{[randomForestSRC]{var.select}})
 #'
-#' @param object A \code{randomForestSRC::rfsrc} object, \code{randomForestSRC::predict}
-#'  object or the list from the \code{randomForestSRC::var.select.rfsrc} function.
-#' @param ... optional arguments passed to the \code{randomForestSRC::var.select} function 
-#'  if operating on an \code{randomForestSRC::rfsrc} object. 
+#' @param object A \code{[randomForestSRC]{rfsrc}} object, \code{[randomForestSRC]{predict}}
+#'  object or the list from the \code{[randomForestSRC]{var.select.rfsrc}} function.
+#' @param ... optional arguments passed to the \code{[randomForestSRC]{var.select}} function 
+#'  if operating on an \code{[randomForestSRC]{rfsrc}} object. 
 #' 
-#' @description the \code{randomForestSRC::var.select} function implements 
+#' @description the \code{[randomForestSRC]{var.select}} function implements 
 #' random forest variable selection using tree minimal depth methodology. The 
 #' \code{gg_minimal_depth} 
-#' function takes the output from \code{randomForestSRC::var.select} and creates a 
+#' function takes the output from \code{[randomForestSRC]{var.select}} and creates a 
 #' \code{data.frame} formatted for the \code{\link{plot.gg_minimal_depth}} function.
 #'  
 #' @return \code{gg_minimal_depth} object, A modified list of variables from the 
-#' \code{randomForestSRC::var.select} function, ordered by minimal depth rank. 
+#' \code{[randomForestSRC]{var.select}} function, ordered by minimal depth rank. 
 #' 
 #' @aliases gg_minimal_depth gg_minimal_depth.rfsrc
 #' 
-#' @seealso \code{randomForestSRC::var.select} \code{\link{plot.gg_minimal_depth}}
+#' @seealso \code{[randomForestSRC]{var.select}} \code{\link{plot.gg_minimal_depth}}
 #' 
 #' @importFrom randomForestSRC var.select
 #' 
@@ -45,7 +45,7 @@
 #' ## -------- iris data
 #' ## You can build a randomForest
 #' # rfsrc_iris <- rfsrc(Species ~ ., data = iris)
-#' # varsel_iris <- var.select(rfsrc_iris)
+#' # varsel_iris <- randomForestSRC::var.select(rfsrc_iris)
 #' # ... or load a cached randomForestSRC object
 #' data(varsel_iris, package="ggRandomForests")
 #' 
@@ -61,7 +61,7 @@
 #' \dontrun{
 #' ## -------- air quality data
 #' # rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
-#' # varsel_airq <- var.select(rfsrc_airq)
+#' # varsel_airq <- randomForestSRC::var.select(rfsrc_airq)
 #' # ... or load a cached randomForestSRC object
 #' data(varsel_airq, package="ggRandomForests")
 #' 
@@ -95,7 +95,7 @@
 #' ## randomized trial of two treatment regimens for lung cancer
 #' # data(veteran, package = "randomForestSRC")
 #' # rfsrc_veteran <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
-#' # varsel_veteran <- var.select(rfsrc_veteran)
+#' # varsel_veteran <- randomForestSRC::var.select(rfsrc_veteran)
 #' # Load a cached randomForestSRC object
 #' data(varsel_veteran, package="ggRandomForests")
 #' 
@@ -118,7 +118,7 @@ gg_minimal_depth <- function (object, ...) {
 gg_minimal_depth.rfsrc <- function (object, ...){
   
   if (inherits(object, "rfsrc") == TRUE){
-    vsel <- var.select(object, ...)
+    vsel <- randomForestSRC::var.select(object, ...)
   }else if (!is.null(object$varselect)) {
     # Test for variable selection minimal depth object
     vsel <- object
