@@ -62,11 +62,11 @@ nelson <- function(interval, censor, data, by=NULL, weight=NULL,...){
   # Kaplan-Meier analysis
   
   # Kaplan-Meier analysis
-  srv <- Surv(time=data[,interval], event=data[,censor])
+  srv <- survival::Surv(time=data[,interval], event=data[,censor])
   if(is.null(by)){
-    srv_tab <- survfit(srv~1,data, ...)
+    srv_tab <- survival::survfit(srv~1, ...)
   }else{
-    srv_tab <- survfit(srv~strata(data[,by]),data, ...)
+    srv_tab <- survival::survfit(srv~survival::strata(data[,by]), ...)
   }
   #
   # OR for stratification on 
