@@ -19,14 +19,14 @@
 #' Predicted response plot from a \code{\link{gg_rfsrc}} object.
 #' 
 #' Plot the predicted response from a \code{\link{gg_rfsrc}} object, the 
-#' \code{randomForestSRC::rfsrc} prediction, using the OOB prediction from the forest.
+#' \code{\link[randomForestSRC]{rfsrc}} prediction, using the OOB prediction from the forest.
 #'  
-#' @param x \code{\link{gg_rfsrc}} object created from a \code{randomForestSRC::rfsrc} object
+#' @param x \code{\link{gg_rfsrc}} object created from a \code{\link[randomForestSRC]{rfsrc}} object
 #' @param ... arguments passed to \code{\link{gg_rfsrc}}.
 #' 
 #' @return \code{ggplot} object
 #' 
-#' @seealso \code{\link{gg_rfsrc}} \code{randomForestSRC::rfsrc}
+#' @seealso \code{\link{gg_rfsrc}} \code{\link[randomForestSRC]{rfsrc}}
 #' 
 #' @references
 #' Breiman L. (2001). Random forests, Machine Learning, 45:5-32.
@@ -99,8 +99,8 @@
 #' 
 #' 
 #' }
-#' @importFrom ggplot2 ggplot aes_string geom_step geom_ribbon labs geom_point geom_smooth geom_jitter geom_boxplot theme element_blank
-#' @importFrom reshape2 melt
+#' @importFrom ggplot2 ggplot aes_string geom_step geom_ribbon labs geom_point geom_jitter geom_boxplot theme element_blank
+#' @importFrom tidyr gather_
 #' 
 #' @export
 plot.gg_rfsrc <- function(x,
@@ -126,7 +126,9 @@ plot.gg_rfsrc <- function(x,
                      outlier.colour = "transparent", fill="transparent", notch = TRUE, ...) +
         theme(axis.ticks = element_blank(), axis.text.x = element_blank())
     }else{
-      gg_dta.mlt <- melt(gg_dta, id.vars="y")
+      gathercols <- colnames(gg_dta)[-which(colnames(gg_dta) == "y")]
+      gg_dta.mlt <- tidyr::gather_(gg_dta, "variable", "value", gathercols)
+      
       gg_plt <- ggplot(gg_dta.mlt, aes_string(x="variable",y="value")) +
         geom_jitter(aes_string(color="y",shape="y"), alpha=.5)
     }
