@@ -21,8 +21,6 @@
 #' @param x a \code{\link{gg_minimal_depth}} object.
 #' @param ... optional arguments
 #' 
-#' @export print.gg_minimal_depth
-#' 
 #' @examples
 #' ## ------------------------------------------------------------
 #' ## classification example
@@ -34,12 +32,13 @@
 #' data(varsel_iris, package="ggRandomForests")
 #' 
 #' # Get a data.frame containing minimaldepth measures
-#' gg_dta<- gg_minimal_depth(varsel_iris)
+#' gg_dta <- gg_minimal_depth(varsel_iris)
 #' print(gg_dta)
 #' 
 #' ## ------------------------------------------------------------
 #' ## regression example
 #' ## ------------------------------------------------------------
+#' \dontrun{
 #' # ... or load a cached randomForestSRC object
 #' data(varsel_airq, package="ggRandomForests")
 #' 
@@ -48,9 +47,20 @@
 #' print(gg_dta)
 #' 
 #' # To nicely print a rfsrc::var.select output... 
-#' print.gg_minimal_depth(varsel_airq)
+#' print(varsel_airq)
+#' }
 #' 
+#' # ... or load a cached randomForestSRC object
+#' data(varsel_Boston, package="ggRandomForests")
 #' 
+#' # Get a data.frame containing minimaldepth measures
+#' gg_dta<- gg_minimal_depth(varsel_Boston)
+#' print(gg_dta)
+#' 
+#' # To nicely print a rfsrc::var.select output... 
+#' print(varsel_Boston)
+#' 
+#' @export
 print.gg_minimal_depth <- function(x, ...){
   gg_dta <- x
   
@@ -70,11 +80,11 @@ print.gg_minimal_depth <- function(x, ...){
   cat("-----------------------------------------------------------\n")
   cat("\n")
   cat("Top variables:\n")
-  vSel <- data.frame(gg_dta$varselect[1:gg_dta$modelsize, 
-                                      -which(colnames(gg_dta$varselect)=="names"), 
+  v_sel <- data.frame(gg_dta$varselect[1:gg_dta$modelsize, 
+                                      -which(colnames(gg_dta$varselect) == "names"), 
                                       drop = FALSE])
   
-  print(vSel, digits=3)
+  print(v_sel, digits=3)
   
   cat("-----------------------------------------------------------\n")
   
