@@ -19,14 +19,17 @@
 #'
 #' There are five cached data set types:
 #' '\itemize{
-#' \item \code{\link{rfsrc_data}} - \code{randomForestSRC::rfsrc} objects. 
-#' \item \code{\link{varsel_data}} - \code{randomForestSRC::var.select} minimal depth variable 
-#' selection objects.
-#' \item \code{\link{interaction_data}} - \code{randomForestSRC::find.interaction} minimal depth, 
+#' \item \code{\link{rfsrc_data}} - \code{\link[randomForestSRC]{rfsrc}} objects. 
+#' \item \code{\link{varsel_data}} - \code{\link[randomForestSRC]{var.select}} 
+#' minimal depth variable selection objects.
+#' \item \code{\link{interaction_data}} - 
+#' \code{\link[randomForestSRC]{find.interaction}} minimal depth, 
 #' pairwise variable interaction matrices.
-#' \item \code{\link{partial_data}} - \code{randomForestSRC::plot.variable} objects 
+#' \item \code{\link{partial_data}} - \code{\link[randomForestSRC]{plot.variable}} 
+#' objects 
 #' (\code{partial=TRUE}) for partial variable dependence. 
-#' \item \code{\link{partial_coplot_data}} - \code{randomForestSRC::plot.variable} objects 
+#' \item \code{\link{partial_coplot_data}} - 
+#' \code{\link[randomForestSRC]{plot.variable}} objects 
 #' (\code{partial=TRUE}) for partial variable dependence. 
 #' }
 #' 
@@ -40,9 +43,9 @@
 #' \item \code{_veteran} - The \code{veteran} data set (\code{randomForestSRC} package).  
 #' }
 #' 
-#' @seealso \code{iris} \code{airq} \code{mtcars} \code{MASS::Boston} 
-#' \code{randomForestSRC::pbc}
-#' \code{randomForestSRC::veteran} 
+#' @seealso \code{iris} \code{airq} \code{mtcars} \code{\link[MASS]{Boston}} 
+#' \code{\link[randomForestSRC]{pbc}}
+#' \code{\link[randomForestSRC]{veteran}} 
 #' \code{\link{rfsrc_data}} 
 #' \code{\link{varsel_data}}
 #' \code{\link{interaction_data}}
@@ -50,12 +53,9 @@
 #' \code{\link{partial_coplot_data}}
 #' 
 #' @importFrom randomForestSRC rfsrc var.select plot.variable find.interaction
-#' @importFrom parallel mclapply
-#' @export
+#' @importFrom utils data
 #' 
-# # @export rf_cache_datasets
-# # @aliases rfsrc_cache_datasets rf_cache_datasets
-
+#' @export
 rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
   dta <- new.env()
   
@@ -88,63 +88,90 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
   
   if("airq" %in% set){
     cat("airq: randomForest\n")
-    if(!test)
-      rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute", ...)
+    data(airquality, package="datasets", envir=dta)
+    airquality <- dta$airquality
     
-    if(save) save(rfsrc_airq, file=paste(pth, "rfsrc_airq.rda", sep=""), compress="xz")
+    if(!test)
+      rfsrc_airq <- randomForestSRC::rfsrc(Ozone ~ ., data = airquality, 
+                                           na.action = "na.impute", ...)
+    
+    if(save) save(rfsrc_airq, file=paste(pth, "rfsrc_airq.rda", sep=""),
+                  compress="xz")
     
     cat("\nairq: RF minimal depth\n")
-    if(!test) varsel_airq <- var.select(rfsrc_airq)
+    if(!test) varsel_airq <- randomForestSRC::var.select(rfsrc_airq)
     
-    if(save) save(varsel_airq, file=paste(pth, "varsel_airq.rda", sep=""), compress="xz")
+    if(save) save(varsel_airq, file=paste(pth, "varsel_airq.rda", sep=""), 
+                  compress="xz")
     
     cat("airq: RF interactions\n")
-    if(!test) interaction_airq <- find.interaction(rfsrc_airq)
-    if(save) save(interaction_airq, file=paste(pth, "interaction_airq.rda", sep=""), compress="xz")
+    if(!test) interaction_airq <- randomForestSRC::find.interaction(rfsrc_airq)
+    if(save) save(interaction_airq, 
+                  file=paste(pth, "interaction_airq.rda", sep=""), 
+                  compress="xz")
     
     cat("airq: RF partial dependence\n")
-    if(!test) partial_airq <- plot.variable(rfsrc_airq,
-                                            partial=TRUE, show.plots=FALSE)
-    if(save) save(partial_airq, file=paste(pth, "partial_airq.rda", sep=""), compress="xz")
+    if(!test) partial_airq <- randomForestSRC::plot.variable(rfsrc_airq,
+                                                             partial=TRUE, show.plots=FALSE)
+    if(save) save(partial_airq, file=paste(pth, "partial_airq.rda", sep=""), 
+                  compress="xz")
   }
   
   if("iris" %in% set){
+    data(iris, package="datasets",
+         envir = dta)
+    iris <- dta$iris
     cat("iris: randomForest\n")
-    if(!test) rfsrc_iris <- rfsrc(Species ~., data = iris, ...)
-    if(save) save(rfsrc_iris, file=paste(pth, "rfsrc_iris.rda", sep=""), compress="xz")
+    if(!test) rfsrc_iris <- randomForestSRC::rfsrc(Species ~., 
+                                                   data = iris, ...)
+    if(save) save(rfsrc_iris, file=paste(pth, "rfsrc_iris.rda", sep=""), 
+                  compress="xz")
     
     cat("\niris: RF minimal depth\n")
-    if(!test)  varsel_iris <- var.select(rfsrc_iris)
-    if(save) save(varsel_iris, file=paste(pth, "varsel_iris.rda", sep=""), compress="xz")
+    if(!test)  varsel_iris <- randomForestSRC::var.select(rfsrc_iris)
+    if(save) save(varsel_iris, file=paste(pth, "varsel_iris.rda", sep=""), 
+                  compress="xz")
     
     cat("iris: RF interactions\n")
-    if(!test) interaction_iris <- find.interaction(rfsrc_iris)
-    if(save) save(interaction_iris, file=paste(pth, "interaction_iris.rda", sep=""), compress="xz")
+    if(!test) interaction_iris <- randomForestSRC::find.interaction(rfsrc_iris)
+    if(save) save(interaction_iris, 
+                  file=paste(pth, "interaction_iris.rda", sep=""), 
+                  compress="xz")
     
     cat("iris: RF partial dependence\n")
-    if(!test) partial_iris <- plot.variable(rfsrc_iris,
-                                            partial=TRUE, show.plots=FALSE)
-    if(save) save(partial_iris, file=paste(pth, "partial_iris.rda", sep=""), compress="xz")
+    if(!test) partial_iris <- randomForestSRC::plot.variable(rfsrc_iris,
+                                                             partial=TRUE, show.plots=FALSE)
+    if(save) save(partial_iris, file=paste(pth, "partial_iris.rda", sep=""), 
+                  compress="xz")
   }
   
-  
   if("mtcars" %in% set){
+    data(mtcars, package="datasets",
+         envir = dta)
+    mtcars <- dta$mtcars
     cat("mtcars: randomForest\n")
-    if(!test) rfsrc_mtcars <- rfsrc(mpg ~ ., data = mtcars, ...)
-    if(save) save(rfsrc_mtcars, file=paste(pth, "rfsrc_mtcars.rda", sep=""), compress="xz")
+    if(!test) rfsrc_mtcars <- randomForestSRC::rfsrc(mpg ~ ., 
+                                                     data = mtcars, ...)
+    if(save) save(rfsrc_mtcars, file=paste(pth, "rfsrc_mtcars.rda", sep=""), 
+                  compress="xz")
     
     cat("\nmtcars: RF minimal depth\n")
-    if(!test) varsel_mtcars <- var.select(rfsrc_mtcars)
-    if(save) save(varsel_mtcars, file=paste(pth, "varsel_mtcars.rda", sep=""), compress="xz")
+    if(!test) varsel_mtcars <- randomForestSRC::var.select(rfsrc_mtcars)
+    if(save) save(varsel_mtcars, file=paste(pth, "varsel_mtcars.rda", sep=""), 
+                  compress="xz")
     
     cat("mtcars: RF interactions\n")
-    if(!test) interaction_mtcars <- find.interaction(rfsrc_mtcars)
-    if(save) save(interaction_mtcars, file=paste(pth, "interaction_mtcars.rda", sep=""), compress="xz")
+    if(!test) interaction_mtcars <- randomForestSRC::find.interaction(rfsrc_mtcars)
+    if(save) save(interaction_mtcars, 
+                  file=paste(pth, "interaction_mtcars.rda", sep=""), 
+                  compress="xz")
     
     cat("mtcars: RF partial dependence\n")
-    if(!test) partial_mtcars <- plot.variable(rfsrc_mtcars,
-                                              partial=TRUE, show.plots=FALSE)
-    if(save) save(partial_mtcars, file=paste(pth, "partial_mtcars.rda", sep=""), compress="xz")
+    if(!test) partial_mtcars <- randomForestSRC::plot.variable(rfsrc_mtcars,
+                                                               partial=TRUE, show.plots=FALSE)
+    if(save) save(partial_mtcars, 
+                  file=paste(pth, "partial_mtcars.rda", sep=""), 
+                  compress="xz")
   }
   if("Boston" %in% set){
     data(Boston, package="MASS",
@@ -154,34 +181,40 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
     Boston$chas <- as.logical(Boston$chas)
     
     cat("Boston: randomForest\n")
-    if(!test) rfsrc_Boston <- rfsrc(medv~., data=Boston, ...)
+    if(!test) rfsrc_Boston <- randomForestSRC::rfsrc(medv~., data=Boston, ...)
     else{
       data(rfsrc_Boston, package="ggRandomForests",
            envir = dta)
       rfsrc_Boston <- dta$rfsrc_Boston
     }
-    if(save) save(rfsrc_Boston, file=paste(pth, "rfsrc_Boston.rda", sep=""), compress="xz")
+    if(save) save(rfsrc_Boston, file=paste(pth, "rfsrc_Boston.rda", sep=""), 
+                  compress="xz")
     
     cat("\nBoston: RF minimal depth\n")
-    if(!test) varsel_Boston <- var.select(rfsrc_Boston)
-    if(save) save(varsel_Boston, file=paste(pth, "varsel_Boston.rda", sep=""), compress="xz")
+    if(!test) varsel_Boston <- randomForestSRC::var.select(rfsrc_Boston)
+    if(save) save(varsel_Boston, file=paste(pth, "varsel_Boston.rda", sep=""), 
+                  compress="xz")
     
     cat("Boston: RF interactions\n")
-    if(!test) interaction_Boston <- find.interaction(rfsrc_Boston)
-    if(save) save(interaction_Boston, file=paste(pth, "interaction_Boston.rda", sep=""), compress="xz")
+    if(!test) interaction_Boston <- randomForestSRC::find.interaction(rfsrc_Boston)
+    if(save) save(interaction_Boston, 
+                  file=paste(pth, "interaction_Boston.rda", sep=""), 
+                  compress="xz")
     
     cat("Boston: RF partial dependence\n(this will take a little while...)\n")
-    if(!test) partial_Boston <- plot.variable(rfsrc_Boston,
-                                              xvar.names=varsel_Boston$topvars,
-                                              sorted=FALSE,
-                                              partial=TRUE, 
-                                              show.plots=FALSE)
-    if(save) save(partial_Boston, file=paste(pth, "partial_Boston.rda", sep=""), compress="xz")
+    if(!test) partial_Boston <- randomForestSRC::plot.variable(rfsrc_Boston,
+                                                               xvar.names=varsel_Boston$topvars,
+                                                               sorted=FALSE,
+                                                               partial=TRUE, 
+                                                               show.plots=FALSE)
+    if(save) save(partial_Boston, file=paste(pth, "partial_Boston.rda", sep=""), 
+                  compress="xz")
     
     cat("\nBoston: RF partial coplots\n\tlstat by rm groups\n(this will take a little longer...)\n")
     rm_pts <- quantile_pts(rfsrc_Boston$xvar$rm, groups=6, intervals=TRUE)
     rm_grp <- cut(rfsrc_Boston$xvar$rm, breaks=rm_pts)
-    if(!test) partial_coplot_Boston <- gg_partial_coplot(rfsrc_Boston, xvar="lstat", 
+    if(!test) partial_coplot_Boston <- gg_partial_coplot(rfsrc_Boston, 
+                                                         xvar="lstat", 
                                                          groups=rm_grp,
                                                          show.plots=FALSE)
     
@@ -190,9 +223,11 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
                   compress="xz")
     
     cat("\nBoston: RF partial coplots\n\trm by lstat groups\n(so will this...)\n")
-    lstat_pts <- quantile_pts(rfsrc_Boston$xvar$lstat, groups=6, intervals=TRUE)
+    lstat_pts <- quantile_pts(rfsrc_Boston$xvar$lstat, groups=6, 
+                              intervals=TRUE)
     lstat_grp <- cut(rfsrc_Boston$xvar$lstat, breaks=lstat_pts)
-    if(!test) partial_coplot_Boston2 <- gg_partial_coplot(rfsrc_Boston, xvar="rm", 
+    if(!test) partial_coplot_Boston2 <- gg_partial_coplot(rfsrc_Boston,
+                                                          xvar="rm", 
                                                           groups=lstat_grp,
                                                           show.plots=FALSE)
     
@@ -225,7 +260,7 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
         }
       }
       if(!is.logical(pbc[, ind]) & 
-           length(unique(pbc[which(!is.na(pbc[,ind])),ind])) <= 5) {
+         length(unique(pbc[which(!is.na(pbc[,ind])),ind])) <= 5) {
         pbc[,ind] <- factor(pbc[,ind])
       }
     }
@@ -244,31 +279,40 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
     # Create a test set from the remaining patients
     pbc.test <- pbc[which(is.na(pbc$treatment)),]
     
-    if(!test) rfsrc_pbc <- rfsrc(Surv(years, status) ~ ., dta.train, nsplit = 10,
-                                 na.action="na.impute", ...)
-    if(save) save(rfsrc_pbc, file=paste(pth, "rfsrc_pbc.rda", sep=""), compress="xz")
+    if(!test) rfsrc_pbc <- randomForestSRC::rfsrc(Surv(years, status) ~ ., 
+                                                  dta.train, nsplit = 10,
+                                                  na.action="na.impute", ...)
+    if(save) save(rfsrc_pbc, 
+                  file=paste(pth, "rfsrc_pbc.rda", sep=""), 
+                  compress="xz")
     
     cat("pbc: randomForest predict\n")
     # Predict survival for 106 patients not in randomized trial
     if(!test)  rfsrc_pbc_test <- predict(rfsrc_pbc, 
                                          newdata = pbc.test,
                                          na.action = "na.impute")
-    if(save) save(rfsrc_pbc_test, file=paste(pth, "rfsrc_pbc_test.rda", sep=""), compress="xz")
+    if(save) save(rfsrc_pbc_test, 
+                  file=paste(pth, "rfsrc_pbc_test.rda", sep=""), 
+                  compress="xz")
     
     # Print prediction summary  
     rfsrc_pbc_test
     cat("pbc: RF minimal depth\n")
-    if(!test) varsel_pbc <- var.select(rfsrc_pbc)
+    if(!test) varsel_pbc <- randomForestSRC::var.select(rfsrc_pbc)
     else{
       data(varsel_pbc, package="ggRandomForests",
            envir = dta)
       varsel_pbc <- dta$varsel_pbc
     }
-    if(save) save(varsel_pbc, file=paste(pth, "varsel_pbc.rda", sep=""), compress="xz")
+    if(save) save(varsel_pbc, 
+                  file=paste(pth, "varsel_pbc.rda", sep=""), 
+                  compress="xz")
     
     cat("pbc: RF interactions\n")
-    if(!test) interaction_pbc <- find.interaction(rfsrc_pbc)
-    if(save) save(interaction_pbc, file=paste(pth, "interaction_pbc.rda", sep=""), compress="xz")
+    if(!test) interaction_pbc <- randomForestSRC::find.interaction(rfsrc_pbc)
+    if(save) save(interaction_pbc, 
+                  file=paste(pth, "interaction_pbc.rda", sep=""), 
+                  compress="xz")
     
     # Calculate the partial dependence
     cat("pbc: RF partial plots\n(this will take a little while...)\n")
@@ -277,19 +321,22 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
     
     cat("pbc: xvar: ", xvar)
     
-    if(!test) partial_pbc <- mclapply(c(1, 3, 5), function(tm){
-      plot.variable(rfsrc_pbc, surv.type = "surv", 
-                    time = tm, sorted = FALSE, 
-                    xvar.names = xvar, partial = TRUE, 
-                    show.plots = FALSE)
+    if(!test) partial_pbc <- lapply(c(1, 3, 5), function(tm){
+      randomForestSRC::plot.variable(rfsrc_pbc, surv.type = "surv", 
+                                     time = tm, sorted = FALSE, 
+                                     xvar.names = xvar, partial = TRUE, 
+                                     show.plots = FALSE)
     })
     
-    if(save) save(partial_pbc, file=paste(pth, "partial_pbc.rda", sep=""), compress="xz")
+    if(save) save(partial_pbc, 
+                  file=paste(pth, "partial_pbc.rda", sep=""), 
+                  compress="xz")
     
     cat("pbc: RF partial coplots\n(this will take a little while...)\n")
     cat("pbc: bili/albumin")
     ggvar <- gg_variable(rfsrc_pbc, time=1)
-    albumin_cts <- quantile_pts(ggvar$albumin, groups = 6, intervals = TRUE)
+    albumin_cts <- quantile_pts(ggvar$albumin, groups = 6, 
+                                intervals = TRUE)
     albumin_grp <- cut(ggvar$albumin, breaks = albumin_cts)
     
     if(!test) 
@@ -300,7 +347,9 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
                                               show.plots = FALSE)
     
     
-    if(save) save(partial_coplot_pbc, file=paste(pth, "partial_coplot_pbc.rda", sep=""), compress="xz")
+    if(save) save(partial_coplot_pbc, 
+                  file=paste(pth, "partial_coplot_pbc.rda", sep=""), 
+                  compress="xz")
     cat("pbc: albumin/bili")
     # Find intervals with similar number of observations.
     bili_cts <- quantile_pts(ggvar$bili, groups = 6, intervals = TRUE)
@@ -319,7 +368,9 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
                                                show.plots = FALSE)
     
     
-    if(save) save(partial_coplot_pbc2, file=paste(pth, "partial_coplot_pbc2.rda", sep=""), compress="xz")
+    if(save) save(partial_coplot_pbc2, 
+                  file=paste(pth, "partial_coplot_pbc2.rda", sep=""), 
+                  compress="xz")
   }
   
   if("veteran" %in% set){
@@ -345,7 +396,7 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
         }
       }
       if(!is.logical(vet[, ind]) & 
-           length(unique(vet[which(!is.na(vet[,ind])),ind])) <= 5) {
+         length(unique(vet[which(!is.na(vet[,ind])),ind])) <= 5) {
         vet[,ind] <- factor(vet[,ind])
       }
     }
@@ -353,28 +404,30 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
     dta$veteran <- vet
     
     cat("veteran: randomForest\n")
-    if(!test) rfsrc_veteran <- rfsrc(Surv(time, status) ~ ., data = dta$veteran, ...)
+    if(!test) rfsrc_veteran <- randomForestSRC::rfsrc(Surv(time, status) ~ ., 
+                                                      data = dta$veteran, ...)
     
     if(save) save(rfsrc_veteran, 
                   file=paste(pth, "rfsrc_veteran.rda", sep=""), compress="xz")
     
     cat("\nveteran: RF minimal depth\n")
-    if(!test) varsel_veteran <- var.select(rfsrc_veteran)
+    if(!test) varsel_veteran <- randomForestSRC::var.select(rfsrc_veteran)
     if(save) save(varsel_veteran, 
                   file=paste(pth, "varsel_veteran.rda", sep=""), compress="xz")
     
     cat("veteran: RF interactions\n")
-    if(!test) interaction_veteran <- find.interaction(rfsrc_veteran)
+    if(!test) interaction_veteran <- randomForestSRC::find.interaction(rfsrc_veteran)
     if(save) save(interaction_veteran, 
-                  file=paste(pth, "interaction_veteran.rda", sep=""), compress="xz")
+                  file=paste(pth, "interaction_veteran.rda", sep=""), 
+                  compress="xz")
     
     cat("veteran:  RF partial plots\n(this will take a little while...)\n")
-    if(!test) partial_veteran <- mclapply(c(30, 180), function(tm){
-      plot.variable(rfsrc_veteran, 
-                    surv.type = "surv", 
-                    partial = TRUE, 
-                    time=tm,
-                    show.plots=FALSE)
+    if(!test) partial_veteran <- lapply(c(30, 180), function(tm){
+      randomForestSRC::plot.variable(rfsrc_veteran, 
+                                     surv.type = "surv", 
+                                     partial = TRUE, 
+                                     time=tm,
+                                     show.plots=FALSE)
     })
     
     if(save) save(partial_veteran, 
@@ -405,7 +458,8 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
 #   
 #   if("airq" %in% set){
 #     cat("airq: randomForest\n")
-#     if(!test) rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute", ...)
+#     if(!test) rfsrc_airq <- randomForestSRC::rfsrc(Ozone ~ ., 
+#         data = airquality, na.action = "na.impute", ...)
 #     if(save) save(rfsrc_airq, file=paste(pth, "rfsrc_airq.rda", sep=""), compress="xz")
 #     
 #     cat("airq: RF partial dependence\n")
@@ -414,7 +468,7 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
 #   
 #   if("iris" %in% set){
 #     cat("iris: randomForest\n")
-#     if(!test) rfsrc_iris <- rfsrc(Species ~., data = iris, ...)
+#     if(!test) rfsrc_iris <- randomForestSRC::rfsrc(Species ~., data = iris, ...)
 #     if(save) save(rfsrc_iris, file=paste(pth, "rfsrc_iris.rda", sep=""), compress="xz")
 #     
 #     cat("iris: RF partial dependence\n")
@@ -423,7 +477,7 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
 #   
 #   if("mtcars" %in% set){
 #     cat("mtcars: randomForest\n")
-#     if(!test) rfsrc_mtcars <- rfsrc(mpg ~ ., data = mtcars, ...)
+#     if(!test) rfsrc_mtcars <- randomForestSRC::rfsrc(mpg ~ ., data = mtcars, ...)
 #     if(save) save(rfsrc_mtcars, file=paste(pth, "rfsrc_mtcars.rda", sep=""), compress="xz")
 #     
 #     cat("mtcars: RF partial dependence\n")
@@ -436,7 +490,7 @@ rfsrc_cache_datasets <- function(set=NA, save=TRUE, pth, ...){
 #     Boston$chas <- as.logical(Boston$chas)
 #     
 #     cat("Boston: randomForest\n")
-#     if(!test) rfsrc_Boston <- rfsrc(medv~., data=Boston, ...)
+#     if(!test) rfsrc_Boston <- randomForestSRC::rfsrc(medv~., data=Boston, ...)
 #     if(save) save(rfsrc_Boston, file=paste(pth, "rfsrc_Boston.rda", sep=""), compress="xz")
 #     
 #     cat("Boston: RF partial dependence\n(this will take a little while...)\n")
