@@ -1,11 +1,7 @@
 # testthat for gg_vimp function
 context("gg_vimp tests")
 
-test_that("gg_vimp classifications",{
-  ## IF we want to build the forest every time...
-  #   rfsrc_iris <- rfsrc(Species ~ ., data = iris)
-  # rfsrc_iris <- var.select(rfsrc_iris)
-  
+test_that("gg_vimp classifications", {  
   ## Load the cached forest
   data(rfsrc_iris, package="ggRandomForests")
   
@@ -16,78 +12,163 @@ test_that("gg_vimp classifications",{
   expect_equal(rfsrc_iris$family, "class")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_vimp(rfsrc_iris)
+  gg_dta <- gg_vimp(rfsrc_iris)
   
   # Test object type
-  expect_is(ggrf.obj, "gg_vimp")
+  expect_is(gg_dta, "gg_vimp")
   
   # Test varselect is the same
- #expect_equivalent(select(ggrf.obj$varselect, -names), rfsrc_iris$importance)
+  #expect_equivalent(select(gg_dta$varselect, -names), rfsrc_iris$importance)
   
   ## Test plotting the gg_error object
-  gg.obj <- plot.gg_vimp(ggrf.obj)
+  gg_plt <- plot(gg_dta)
   
   # Test return is s ggplot object
-  expect_is(gg.obj, "ggplot")
+  expect_is(gg_plt, "ggplot")
+  
+  # Grab only one class... by number.
+  gg_dta <- gg_vimp(rfsrc_iris, which.outcome=2)
+  
+  # Test object type
+  expect_is(gg_dta, "gg_vimp")
+  ## Test plotting the gg_error object
+  gg_plt <- plot(gg_dta)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
+  # Grab only one class... by number - for the overall model.
+  gg_dta <- gg_vimp(rfsrc_iris, which.outcome=0)
+  
+  # Test object type
+  expect_is(gg_dta, "gg_vimp")
+  ## Test plotting the gg_error object
+  gg_plt <- plot(gg_dta)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
+  # Grab only one class... by name - for the overall model.
+  gg_dta <- gg_vimp(rfsrc_iris, which.outcome="all")
+  
+  # Test object type
+  expect_is(gg_dta, "gg_vimp")
+  ## Test plotting the gg_error object
+  gg_plt <- plot(gg_dta)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
+  # Grab only one class... by name - for the overall model.
+  gg_dta <- gg_vimp(rfsrc_iris, which.outcome="setosa")
+  
+  # Test object type
+  expect_is(gg_dta, "gg_vimp")
+  ## Test plotting the gg_error object
+  gg_plt <- plot(gg_dta)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
+  
+  # Grab only one class... by name - that doesn't exist.
+  expect_error(gg_vimp(rfsrc_iris, which.outcome="nothing special"))
+  
+  # Grab only one class... by number - that doesn't exist.
+  expect_error(gg_vimp(rfsrc_iris, which.outcome=200))
+  
+  ## Single class/
+  iris2 <- iris
+  iris2$spec <- factor(as.character(iris2$Species) == "setosa")
+  iris2 <- iris2[,-which(colnames(iris2) == "Species")]
+  
+  rf <- rfsrc(spec~., iris2)
+  
+  gg_dta <- gg_vimp(rf)
+  
+  expect_is(gg_dta, "gg_vimp")
+  
+  # Test passing in the wrong object
+  expect_error(gg_vimp(gg_dta))
+  expect_error(gg_vimp.rfsrc(gg_dta))
+  
 })
 
 
 test_that("gg_vimp survival",{
-  
-  ## IF we want to build the forest every time...
-  #   data(veteran, package = "randomForestSRC")
-  #   rfsrc_veteran <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
-  #   rfsrc_veteran <- var.select(rfsrc_veteran)
   ## Load the cached forest
-  data(rfsrc_veteran, package="ggRandomForests")
+  data(rfsrc_pbc, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(rfsrc_veteran, "rfsrc")
+  expect_is(rfsrc_pbc, "rfsrc")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_vimp(rfsrc_veteran)
+  gg_dta <- gg_vimp(rfsrc_pbc)
   
   # Test object type
-  expect_is(ggrf.obj, "gg_vimp")
+  expect_is(gg_dta, "gg_vimp")
   
   # Test varselect is the same
-  expect_equal(ggrf.obj$vimp, as.vector(sort(rfsrc_veteran$importance, decreasing=TRUE)))
+  expect_equal(gg_dta$vimp, as.vector(sort(rfsrc_pbc$importance, decreasing=TRUE)))
   
   ## Test plotting the gg_error object
-  gg.obj <- plot.gg_vimp(ggrf.obj)
+  gg_plt <- plot(gg_dta)
   
   # Test return is s ggplot object
-  expect_is(gg.obj, "ggplot")
+  expect_is(gg_plt, "ggplot")
+  
+  ## Test plotting the gg_error object
+  gg_plt <- plot(gg_dta, nvar=5)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
+  
+  expect_is(plot(gg_dta, relative=TRUE), "ggplot")
+  
+  # Test cutting the size down
+  expect_is(gg_dta <- gg_vimp(rfsrc_pbc, n_var=10), "gg_vimp")
+  expect_equal(nrow(gg_dta), 10)
+  expect_is(plot(gg_dta), "ggplot")
+  
+  # Test the relative vimp output and plotting
+  expect_is(gg_dta <- gg_vimp(rfsrc_pbc, relative=TRUE), "gg_vimp")
+  expect_is(plot(gg_dta), "ggplot")
+  
+  expect_is(gg_dta <- gg_vimp(rfsrc_pbc, n_var=10, relative=TRUE), "gg_vimp")
+  expect_is(plot(gg_dta), "ggplot")
+  
+  # Test importance calculations. 
+  # If the forest does not have importance
+  rfsrc_pbc$importance <- NULL
+  expect_warning(gg_dta <- gg_vimp(rfsrc_pbc))
+  expect_is(gg_dta, "gg_vimp")
+  expect_is(plot(gg_dta), "ggplot")
+  
 })
 
 test_that("gg_vimp regression",{
-  
-  ## IF we want to build the forest every time...
-  #   ## New York air quality measurements
-  #   airq.obj <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
-  #   rfsrc_airq <- var.select(rfsrc_airq)
   ## Load the cached forest
-  data(rfsrc_airq, package="ggRandomForests")
+  data(rfsrc_Boston, package="ggRandomForests")
   
   # Test the cached forest type
-  expect_is(rfsrc_airq, "rfsrc")
+  expect_is(rfsrc_Boston, "rfsrc")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_vimp(rfsrc_airq)
+  gg_dta <- gg_vimp(rfsrc_Boston)
   
   # Test object type
-  expect_is(ggrf.obj, "gg_vimp")
+  expect_is(gg_dta, "gg_vimp")
   
   # Test varselect is the same
-  expect_equal(ggrf.obj$vimp, as.vector(sort(rfsrc_airq$importance, decreasing=TRUE)))
+  expect_equal(gg_dta$vimp, as.vector(sort(rfsrc_Boston$importance, decreasing=TRUE)))
   
   ## Test plotting the gg_error object
-  gg.obj <- plot.gg_vimp(ggrf.obj)
+  gg_plt <- plot(gg_dta)
   
   # Test return is s ggplot object
-  expect_is(gg.obj, "ggplot")
+  expect_is(gg_plt, "ggplot")
+  ## Test plotting the gg_error object
+  gg_plt <- plot(gg_dta, relative=TRUE)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
   
-  data(rfsrc_Boston, package="ggRandomForests")
   data(Boston, package="MASS")
   
   cls <- sapply(Boston, class) 
@@ -129,8 +210,10 @@ test_that("gg_vimp regression",{
   st.labs <- as.character(dta.labs$Description)
   names(st.labs) <- names(cls)
   
-  ## Test plotting the gg_error object
+  ## Test plotting the rfsrc object
   gg_plt <- plot.gg_vimp(rfsrc_Boston, lbls=st.labs, relative=TRUE, 
                          bars=rfsrc_Boston$xvar.names)
   expect_is(gg_plt, "ggplot")
+  
+  
 })
\ No newline at end of file
